;; Generated package description from valign.el  -*- no-byte-compile: t -*-
(define-package "valign" "3.1.0.0.20210128.34233" "Visually align tables" '((emacs "26.0")) :keywords '("convenience" "text" "table") :authors '(("Yuan Fu" . "casouri@gmail.com")) :maintainer '("Yuan Fu" . "casouri@gmail.com") :url "https://github.com/casouri/valign")
